import { RemovalPolicy } from 'aws-cdk-lib';
import { CfnCrawler, CfnDatabase } from 'aws-cdk-lib/aws-glue';
import { AddToPrincipalPolicyResult, IPrincipal } from 'aws-cdk-lib/aws-iam';
import { Key } from 'aws-cdk-lib/aws-kms';
import { IBucket } from 'aws-cdk-lib/aws-s3';
import { Construct } from 'constructs';
import { TrackedConstruct } from '../utils';
/**
 * An AWS Glue Data Catalog Database configured with the location and a crawler.
 * @see https://awslabs.github.io/aws-data-solutions-framework/docs/constructs/library/data-catalog-database
 *
 * @example
 * import { Bucket } from 'aws-cdk-lib/aws-s3';
 *
 * new dsf.DataCatalogDatabase(this, 'ExampleDatabase', {
 *    locationBucket: new Bucket(scope, 'LocationBucket'),
 *    locationPrefix: '/databasePath',
 *    name: 'example-db'
 * });
 */
export declare class DataCatalogDatabase extends TrackedConstruct {
    /**
     * The Glue Crawler that is automatically created when `autoCrawl` is set to `true` (default value). This property can be undefined if `autoCrawl` is set to `false`.
     */
    readonly crawler?: CfnCrawler;
    /**
     * The Glue database that's created
     */
    readonly database: CfnDatabase;
    /**
     * The Glue database name with the randomized suffix to prevent name collisions in the catalog
     */
    readonly databaseName: string;
    /**
     * KMS encryption key used by the Crawler
     */
    readonly crawlerLogEncryptionKey?: Key;
    /**
     * Caching constructor properties for internal reuse by constructor methods
     */
    private dataCatalogDatabaseProps;
    constructor(scope: Construct, id: string, props: DataCatalogDatabaseProps);
    /**
     * Grants read access via identity based policy to the principal. This would attach an IAM policy to the principal allowing read access to the database and all its tables.
     * @param principal Principal to attach the database read access to
     * @returns `AddToPrincipalPolicyResult`
     */
    grantReadOnlyAccess(principal: IPrincipal): AddToPrincipalPolicyResult;
    private calculateDefaultTableLevelDepth;
}
/**
 * The Database catalog properties
 */
export interface DataCatalogDatabaseProps {
    /**
     * Database name. Construct would add a randomize suffix as part of the name to prevent name collisions.
     */
    readonly name: string;
    /**
     * S3 bucket where data is stored
     */
    readonly locationBucket: IBucket;
    /**
     * Top level location wwhere table data is stored.
     */
    readonly locationPrefix: string;
    /**
     * When enabled, this automatically creates a top level Glue Crawler that would run based on the defined schedule in the `autoCrawlSchedule` parameter.
     * @default True
     */
    readonly autoCrawl?: boolean;
    /**
     * The schedule when the Crawler would run. Default is once a day at 00:01h.
     * @default `cron(1 0 * * ? *)`
     */
    readonly autoCrawlSchedule?: CfnCrawler.ScheduleProperty;
    /**
     * Encryption key used for Crawler logs
     * @default Create a new key if none is provided
     */
    readonly crawlerLogEncryptionKey?: Key;
    /**
     * Directory depth where the table folders are located. This helps the crawler understand the layout of the folders in S3.
     * @default calculated based on `locationPrefix`
     */
    readonly crawlerTableLevelDepth?: number;
    /**
     * Policy to apply when the bucket is removed from this stack.
     * * @default - RETAIN (The bucket will be orphaned).
     */
    readonly removalPolicy?: RemovalPolicy;
}
