import { RemovalPolicy } from 'aws-cdk-lib';
import { CfnCrawler } from 'aws-cdk-lib/aws-glue';
import { Key } from 'aws-cdk-lib/aws-kms';
import { Construct } from 'constructs';
import { DataCatalogDatabase } from './data-catalog-database';
import { DataLakeStorage } from '../storage';
import { TrackedConstruct } from '../utils';
/**
* Creates AWS Glue Catalog Database for each storage layer. Composed of 3 {@link DataCatalogDatabase} for Bronze, Silver, and Gold data.
* @see https://awslabs.github.io/aws-data-solutions-framework/docs/constructs/library/data-lake-catalog
 *
* @example
* import { Key } from 'aws-cdk-lib/aws-kms';
*
* const logEncryptionKey = new Key(this, 'LogEncryptionKey');
* const storage = new dsf.DataLakeStorage(this, "ExampleStorage");
* const dataLakeCatalog = new dsf.DataLakeCatalog(this, "ExampleDataLakeCatalog", {
*   dataLakeStorage: storage,
*   databaseName: "exampledb",
*   crawlerLogEncryptionKey: logEncryptionKey
* })
*/
export declare class DataLakeCatalog extends TrackedConstruct {
    readonly bronzeCatalogDatabase: DataCatalogDatabase;
    readonly silverCatalogDatabase: DataCatalogDatabase;
    readonly goldCatalogDatabase: DataCatalogDatabase;
    readonly crawlerLogEncryptionKey?: Key;
    /**
     * Constructs a new instance of DataLakeCatalog
     * @param {Construct} scope the Scope of the CDK Construct
     * @param {string} id the ID of the CDK Construct
     * @param {DataLakeCatalogProps} props the DataLakeCatalog properties
     */
    constructor(scope: Construct, id: string, props: DataLakeCatalogProps);
    /**
     * Extract the bucket prefix from the {@link AnalyticsBucket} bucket name.
     * @param {AnalyticsBucket} bucket
     * @returns
     */
    private extractBucketName;
}
/**
 * Properties for the DataLakeCatalog Construct
 */
export interface DataLakeCatalogProps {
    /**
     * Location of data lake files
     */
    readonly dataLakeStorage: DataLakeStorage;
    /**
     * The name of the database in the Glue Data Catalog. This is also used as the prefix inside the data lake bucket.
     * @default Use the bucket name as the database name and / as the prefix
     */
    readonly databaseName?: string;
    /**
     * When enabled, this automatically creates a top level Glue Crawler that would run based on the defined schedule in the `autoCrawlSchedule` parameter.
     * @default True
     */
    readonly autoCrawl?: boolean;
    /**
     * The schedule when the Crawler would run. Default is once a day at 00:01h.
     * @default `cron(1 0 * * ? *)`
     */
    readonly autoCrawlSchedule?: CfnCrawler.ScheduleProperty;
    /**
     * Encryption key used for Crawler logs
     * @default Create a new key if none is provided
     */
    readonly crawlerLogEncryptionKey?: Key;
    /**
     * Directory depth where the table folders are located. This helps the crawler understand the layout of the folders in S3.
     * @default calculated based on `locationPrefix`
     */
    readonly crawlerTableLevelDepth?: number;
    /**
     * Policy to apply when the bucket is removed from this stack.
     * * @default - RETAIN (The bucket will be orphaned).
     */
    readonly removalPolicy?: RemovalPolicy;
}
