import { RemovalPolicy } from 'aws-cdk-lib';
import { Repository } from 'aws-cdk-lib/aws-codecommit';
import { PolicyStatement } from 'aws-cdk-lib/aws-iam';
import { CodePipeline } from 'aws-cdk-lib/pipelines';
import { Construct } from 'constructs';
import { ApplicationStackFactory, SparkImage, TrackedConstruct } from '../../utils';
/**
 * The account information for deploying the Spark Application stack.
 */
export interface AccountInfo {
    /**
     * The account ID to deploy the Spark Application stack
     */
    readonly account: string;
    /**
     * The region to deploy the Spark Application stack
     */
    readonly region: string;
}
/**
 * Properties for SparkEmrCICDPipeline class.
 */
export interface SparkEmrCICDPipelineProps {
    /**
     * The name of the Spark application to be deployed.
     */
    readonly sparkApplicationName: string;
    /**
     * The application Stack to deploy in the different CDK Pipelines Stages
     */
    readonly applicationStackFactory: ApplicationStackFactory;
    /**
     * The path to the folder that contains the CDK Application
     * @default - The root of the repository
     */
    readonly cdkApplicationPath?: string;
    /**
     * The path to the folder that contains the Spark Application
     * @default - The root of the repository
     */
    readonly sparkApplicationPath?: string;
    /**
     * The EMR Spark image to use to run the unit tests
     * @default - EMR v6.12 is used
     */
    readonly sparkImage?: SparkImage;
    /**
     * The path to the Shell script that contains integration tests
     * @default - No integration tests are run
     */
    readonly integTestScript?: string;
    /**
     * The environment variables to create from the Application Stack and to pass to the integration tests.
     * This is used to interact with resources created by the Application Stack from within the integration tests script.
     * Key is the name of the environment variable to create. Value is generally a CfnOutput name from the Application Stack.
     * @default - No environment variables
     */
    readonly integTestEnv?: Record<string, string>;
    /**
     * The IAM policy statements to add permissions for running the integration tests.
     * @default - No permissions
     */
    readonly integTestPermissions?: PolicyStatement[];
    /**
     * The removal policy when deleting the CDK resource.
     * If DESTROY is selected, context value `@aws-data-solutions-framework/removeDataOnDestroy` needs to be set to true.
     * Otherwise the removalPolicy is reverted to RETAIN.
     * @default - The resources are not deleted (`RemovalPolicy.RETAIN`).
     */
    readonly removalPolicy?: RemovalPolicy;
}
/**
 * A CICD Pipeline that tests and deploys a Spark application in cross-account environments using CDK Pipelines.
 * @see https://awslabs.github.io/aws-data-solutions-framework/docs/constructs/library/spark-cicd-pipeline
 *
 * @exampleMetadata fixture=imports-only
 * @example
 * import { Bucket } from 'aws-cdk-lib/aws-s3';
 *
 * interface MyApplicationStackProps extends cdk.StackProps {
 *   readonly stage: dsf.CICDStage;
 * }
 *
 * class MyApplicationStack extends cdk.Stack {
 *   constructor(scope: cdk.Stack, props?: MyApplicationStackProps) {
 *     super(scope, 'MyApplicationStack');
 *     const bucket = new Bucket(this, 'TestBucket', {
 *       autoDeleteObjects: true,
 *       removalPolicy: cdk.RemovalPolicy.DESTROY,
 *     });
 *     new cdk.CfnOutput(this, 'BucketName', { value: bucket.bucketName });
 *   }
 * }
 *
 * class MyStackFactory implements dsf.ApplicationStackFactory {
 *   createStack(scope: cdk.Stack, stage: dsf.CICDStage): cdk.Stack {
 *     return new MyApplicationStack(scope, { stage });
 *   }
 * }
 *
 * class MyCICDStack extends cdk.Stack {
 *   constructor(scope: Construct, id: string) {
 *     super(scope, id);
 *     new dsf.SparkEmrCICDPipeline(this, 'TestConstruct', {
 *        sparkApplicationName: 'test',
 *        applicationStackFactory: new MyStackFactory(),
 *        cdkApplicationPath: 'cdk/',
 *        sparkApplicationPath: 'spark/',
 *        sparkImage: dsf.SparkImage.EMR_6_12,
 *        integTestScript: 'cdk/integ-test.sh',
 *        integTestEnv: {
 *          TEST_BUCKET: 'BucketName',
 *        },
 *     });
 *   }
 * }
 */
export declare class SparkEmrCICDPipeline extends TrackedConstruct {
    /**
     * Extract the path and the script name from a script path
     * @param path the script path
     * @return [path, scriptName]
     */
    private static extractPath;
    /**
     * Build the install commands for the CodeBuild step based on the runtime
     * @param cdkPath the path of the CDK application
     * @param sparkPath the path of the Spark application
     * @return installCommands
     */
    private static synthCommands;
    /**
     * The CodePipeline created as part of the Spark CICD Pipeline
     */
    readonly pipeline: CodePipeline;
    /**
     * The CodeCommit repository created as part of the Spark CICD Pipeline
     */
    readonly repository: Repository;
    /**
     * Construct a new instance of the SparkCICDPipeline class.
     * @param {Construct} scope the Scope of the CDK Construct
     * @param {string} id the ID of the CDK Construct
     * @param {SparkEmrCICDPipelineProps} props the SparkCICDPipelineProps properties
     */
    constructor(scope: Construct, id: string, props: SparkEmrCICDPipelineProps);
    /**
     * Extract PROD and STAGING account IDs and regions from the CDK context
     */
    private getAccountFromContext;
}
