import { IRole } from 'aws-cdk-lib/aws-iam';
import { FailProps } from 'aws-cdk-lib/aws-stepfunctions';
import { CallAwsServiceProps } from 'aws-cdk-lib/aws-stepfunctions-tasks';
import { Construct } from 'constructs';
import { SparkJob, SparkJobProps } from './spark-job';
/**
 * A construct to run Spark Jobs using EMR on EKS.
 * Creates a Step Functions State Machine that orchestrates the Spark Job.
 * @see https://awslabs.github.io/aws-data-solutions-framework/docs/constructs/library/spark-job
 *
 * @example
 * import { JsonPath } from 'aws-cdk-lib/aws-stepfunctions';
 *
 * const job = new dsf.SparkEmrEksJob(this, 'SparkJob', {
 *   jobConfig:{
 *     "Name": JsonPath.format('ge_profile-{}', JsonPath.uuid()),
 *     "VirtualClusterId": "virtualClusterId",
 *     "ExecutionRoleArn": "ROLE-ARN",
 *     "JobDriver": {
 *       "SparkSubmit": {
 *           "EntryPoint": "s3://S3-BUCKET/pi.py",
 *           "EntryPointArguments": [],
 *           "SparkSubmitParameters": "--conf spark.executor.instances=2 --conf spark.executor.memory=2G --conf spark.driver.memory=2G --conf spark.executor.cores=4"
 *       },
 *     }
 *   }
 * } as dsf.SparkEmrEksJobApiProps);
 *
 * new cdk.CfnOutput(this, 'SparkJobStateMachine', {
 *   value: job.stateMachine!.stateMachineArn,
 * });
 */
export declare class SparkEmrEksJob extends SparkJob {
    private constructJobConfig;
    constructor(scope: Construct, id: string, props: SparkEmrEksJobProps | SparkEmrEksJobApiProps);
    /**
     * Returns the props for the Step Functions CallAwsService Construct that starts the Spark job, it calls the [StartJobRun API](https://docs.aws.amazon.com/emr-on-eks/latest/APIReference/API_StartJobRun.html)
     * @see CallAwsService @link[https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_stepfunctions_tasks.CallAwsService.html]
     * @returns CallAwsServiceProps
     */
    protected returnJobStartTaskProps(): CallAwsServiceProps;
    /**
     * Returns the props for the Step Functions CallAwsService Construct that checks the execution status of the Spark job
     * @see CallAwsService @link[https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_stepfunctions_tasks.CallAwsService.html]
     * @returns CallAwsServiceProps
     */
    protected returnJobMonitorTaskProps(): CallAwsServiceProps;
    /**
     * Returns the props for the Step Functions task that handles the failure  if the EMR Serverless job fails.
     * @returns FailProps The error details of the failed Spark Job
     */
    protected returnJobFailTaskProps(): FailProps;
    /**
     * Returns the status of the EMR on EKS job that succeeded  based on the GetJobRun API response
     * @returns string
     */
    protected returnJobStatusSucceed(): string;
    /**
     * Returns the status of the EMR on EKS job that failed based on the GetJobRun API response
     * @returns string
     */
    protected returnJobStatusFailed(): string;
    /**
     * Returns the status of the EMR Serverless job that is cancelled based on the GetJobRun API response
     * @returns string
     */
    protected returnJobStatusCancelled(): string;
    /**
     * Grants the necessary permissions to the Step Functions StateMachine to be able to start EMR on EKS job
     * @param role Step Functions StateMachine IAM role
     */
    protected grantExecutionRole(role: IRole): void;
    /**
     * Set defaults for the EmrOnEksSparkJobApiProps.
     * @param props EmrOnEksSparkJobApiProps
     */
    private setJobApiPropsDefaults;
    /**
     * Set defaults for the EmrOnEksSparkJobProps.
     * @param props EmrOnEksSparkJobProps
     */
    private setJobPropsDefaults;
}
/**
 * Simplified configuration for the EMR Serverless Job.
 * @param name Spark job name @default Autogenerated
 * @param virtualClusterId EMR Serverless application ID
 * @param releaseLabel the EMR runtime to use @default EMR_DEFAULT_VERSION
 * @param executionRoleArn EMR on EKS execution role ARN
 * @param sparkSubmitEntryPoint The entry point for the Spark submit job run. @see @link(https://docs.aws.amazon.com/emr-on-eks/latest/APIReference/API_StartJobRun.html)
 * @param sparkSubmitEntryPointArguments The arguments for the Spark submit job run. @see @link(https://docs.aws.amazon.com/emr-on-eks/latest/APIReference/API_StartJobRun.html)
 * @param sparkSubmitParameters The parameters for the Spark submit job run. @see @link(https://docs.aws.amazon.com/emr-on-eks/latest/APIReference/API_StartJobRun.html)
 * @param applicationConfiguration The override configurations for the application. @see @link(https://docs.aws.amazon.com/emr-on-eks/latest/APIReference/API_ConfigurationOverrides.html#emroneks-Type-ConfigurationOverrides-applicationConfiguration)
 * @param executionTimeoutMinutes Job execution timeout in minutes. @default 30
 * @param maxRetries The maximum number of attempts on the job's driver.
 * @param s3LogUri The Amazon S3 destination URI for log publishing. @default Create new bucket. @see @link(https://docs.aws.amazon.com/emr-on-eks/latest/APIReference/API_S3MonitoringConfiguration.html#emroneks-Type-S3MonitoringConfiguration-logUri)
 * @param cloudWatchLogGroupName CloudWatch log group name for job monitoring.  @see @link(https://docs.aws.amazon.com/emr-on-eks/latest/APIReference/API_CloudWatchMonitoringConfiguration.html#emroneks-Type-CloudWatchMonitoringConfiguration-logGroupName)
 * @param cloudWatchLogGroupStreamPrefix CloudWatch log group stream prefix. @default The name of the spark job. @see @link(https://docs.aws.amazon.com/emr-on-eks/latest/APIReference/API_CloudWatchMonitoringConfiguration.html#emroneks-Type-CloudWatchMonitoringConfiguration-logGroupName)
 * @param tags Tags to be added to the EMR Serverless job. @see @link(https://docs.aws.amazon.com/emr-on-eks/latest/APIReference/API_StartJobRun.html#emroneks-StartJobRun-request-tags)
 */
export interface SparkEmrEksJobProps extends SparkJobProps {
    readonly name: string;
    readonly virtualClusterId: string;
    readonly releaseLabel?: string;
    readonly executionRoleArn: string;
    readonly sparkSubmitEntryPoint: string;
    readonly sparkSubmitEntryPointArguments?: string[];
    readonly sparkSubmitParameters?: string;
    readonly applicationConfiguration?: {
        [key: string]: any;
    };
    readonly executionTimeoutMinutes?: number;
    readonly maxRetries?: number;
    readonly s3LogUri?: string;
    readonly cloudWatchLogGroupName?: string;
    readonly cloudWatchLogGroupStreamPrefix?: string;
    readonly tags?: {
        [key: string]: any;
    };
}
/**
 * Configuration for the EMR on EKS job.
 * Use this interface when EmrOnEksSparkJobProps doesn't give you access to the configuration parameters you need.
 * @param jobConfig The job configuration. @link[https://docs.aws.amazon.com/emr-on-eks/latest/APIReference/API_StartJobRun.html]
 */
export interface SparkEmrEksJobApiProps extends SparkJobProps {
    /**
     * Job execution timeout in minutes. @default 30
     */
    readonly executionTimeoutMinutes?: number;
    /**
     * EMR on EKS Job Configuration.
     * @link[https://docs.aws.amazon.com/emr-on-eks/latest/APIReference/API_StartJobRun.html]
     */
    readonly jobConfig: {
        [key: string]: any;
    };
}
