import { IRole } from 'aws-cdk-lib/aws-iam';
import { FailProps } from 'aws-cdk-lib/aws-stepfunctions';
import { CallAwsServiceProps } from 'aws-cdk-lib/aws-stepfunctions-tasks';
import { Construct } from 'constructs';
import { SparkJob, SparkJobProps } from './spark-job';
/**
 * A construct to run Spark Jobs using EMR Serverless.
 * Creates a State Machine that orchestrates the Spark Job.
 * @see https://awslabs.github.io/aws-data-solutions-framework/docs/constructs/library/spark-job
 *
 * @example
 * import { PolicyDocument, PolicyStatement } from 'aws-cdk-lib/aws-iam';
 * import { JsonPath } from 'aws-cdk-lib/aws-stepfunctions';
 *
 * const myFileSystemPolicy = new PolicyDocument({
 *   statements: [new PolicyStatement({
 *     actions: [
 *       's3:GetObject',
 *     ],
 *     resources: ['*'],
 *   })],
 * });
 *
 *
 * const myExecutionRole = dsf.SparkEmrServerlessRuntime.createExecutionRole(this, 'execRole1', myFileSystemPolicy);
 * const applicationId = "APPLICATION_ID";
 * const job = new dsf.SparkEmrServerlessJob(this, 'SparkJob', {
 *   jobConfig:{
 *     "Name": JsonPath.format('ge_profile-{}', JsonPath.uuid()),
 *     "ApplicationId": applicationId,
 *     "ExecutionRoleArn": myExecutionRole.roleArn,
 *     "JobDriver": {
 *       "SparkSubmit": {
 *           "EntryPoint": "s3://S3-BUCKET/pi.py",
 *           "EntryPointArguments": [],
 *           "SparkSubmitParameters": "--conf spark.executor.instances=2 --conf spark.executor.memory=2G --conf spark.driver.memory=2G --conf spark.executor.cores=4"
 *       },
 *     }
 *   }
 * } as dsf.SparkEmrServerlessJobApiProps);
 *
 * new cdk.CfnOutput(this, 'SparkJobStateMachine', {
 *   value: job.stateMachine!.stateMachineArn,
 * });
 */
export declare class SparkEmrServerlessJob extends SparkJob {
    /**
     * Spark Job execution role. Use this property to add additional IAM permissions if necessary.
     */
    sparkJobExecutionRole?: IRole;
    private constructJobConfig;
    constructor(scope: Construct, id: string, props: SparkEmrServerlessJobProps | SparkEmrServerlessJobApiProps);
    /**
     * Returns the props for the Step Functions CallAwsService Construct that starts the Spark job, it calls the [StartJobRun API](https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_StartJobRun.html)
     * @see CallAwsService @link[https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_stepfunctions_tasks.CallAwsService.html]
     * @returns CallAwsServiceProps
     */
    protected returnJobStartTaskProps(): CallAwsServiceProps;
    /**
     * Returns the props for the Step Functions CallAwsService Construct that checks the execution status of the Spark job, it calls the [GetJobRun API](https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_GetJobRun.html)
     * @see CallAwsService @link[https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_stepfunctions_tasks.CallAwsService.html]
     * @returns CallAwsServiceProps
     */
    protected returnJobMonitorTaskProps(): CallAwsServiceProps;
    /**
     * Returns the props for the step function task that handles the failure if the EMR Serverless job fails.
     * @returns FailProps The error details of the failed Spark Job
     */
    protected returnJobFailTaskProps(): FailProps;
    /**
     * Returns the status of the EMR Serverless job that succeeded based on the GetJobRun API response
     * @returns string
     */
    protected returnJobStatusSucceed(): string;
    /**
     * Returns the status of the EMR Serverless job that failed based on the GetJobRun API response
     * @returns string
     */
    protected returnJobStatusFailed(): string;
    /**
     * Returns the status of the EMR Serverless job that is cancelled based on the GetJobRun API response
     * @returns string
     */
    protected returnJobStatusCancelled(): string;
    /**
     * Grants the necessary permissions to the Step Functions StateMachine to be able to start EMR Serverless job
     * @param role Step Functions StateMachine IAM role
     * @see SparkRuntimeServerless.grantJobExecution
     */
    protected grantExecutionRole(role: IRole): void;
    /**
     * Set defaults for the EmrServerlessSparkJobApiProps.
     * @param props EmrServerlessSparkJobApiProps
     */
    private setJobApiPropsDefaults;
    /**
     * Set defaults for the EmrOnEksSparkJobProps.
     * @param props EmrOnEksSparkJobProps
     */
    private setJobPropsDefaults;
}
/**
 * Simplified configuration for the EMR Serverless Job.
 * @param name Spark job name @default Autogenerated
 * @param applicationId EMR Serverless application ID
 * @param executionRoleArn EMR Serverless execution role ARN
 * @param sparkSubmitEntryPoint The entry point for the Spark submit job run. @see @link(https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_SparkSubmit.html)
 * @param sparkSubmitEntryPointArguments The arguments for the Spark submit job run. @see @link(https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_SparkSubmit.html)
 * @param sparkSubmitParameters The parameters for the Spark submit job run. @see @link(https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_SparkSubmit.html)
 * @param applicationConfiguration The override configurations for the application. @see @link(https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_ConfigurationOverrides.html)
 * @param executionTimeoutMinutes Job execution timeout in minutes. @default 30
 * @param persistentAppUi Enable Persistent UI. @default true @see @link(https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_ManagedPersistenceMonitoringConfiguration.html)
 * @param persistentAppUIKeyArn Persistent application UI encryption key ARN @default AWS Managed default KMS key used @see @link(https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_ManagedPersistenceMonitoringConfiguration.html)
 * @param s3LogUri The Amazon S3 destination URI for log publishing. Example: s3://BUCKET_NAME/ @default Create new bucket. @see @link(https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_S3MonitoringConfiguration.html)
 * @param s3LogUriKeyArn KMS Encryption key for S3 log monitoring bucket. @default AWS Managed default KMS key used. @see @link(https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_S3MonitoringConfiguration.html)
 * @param cloudWatchLogGroupName CloudWatch log group name for job monitoring.  @see @link(https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_CloudWatchLoggingConfiguration.html)
 * @param cloudWatchEncryptionKeyArn CloudWatch log encryption key ARN. @default AWS Managed default KMS key used. @see @link(https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_CloudWatchLoggingConfiguration.html)
 * @param cloudWatchLogGroupStreamPrefix CloudWatch log group stream prefix. @default The name of the spark job. @see @link(https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_CloudWatchLoggingConfiguration.html)
 * @param cloudWatchLogtypes CloudWatch log verbosity type. @default ERROR @see @link(https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_CloudWatchLoggingConfiguration.html)
 * @param tags Tags to be added to the EMR Serverless job. @see @link[https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_StartJobRun.html]
 */
export interface SparkEmrServerlessJobProps extends SparkJobProps {
    readonly name: string;
    readonly applicationId: string;
    readonly executionRoleArn?: string;
    readonly sparkSubmitEntryPoint: string;
    readonly sparkSubmitEntryPointArguments?: string[];
    readonly sparkSubmitParameters?: string;
    readonly applicationConfiguration?: {
        [key: string]: any;
    };
    readonly executionTimeoutMinutes?: number;
    readonly persistentAppUi?: boolean;
    readonly persistentAppUIKeyArn?: string;
    readonly s3LogUri?: string;
    readonly s3LogUriKeyArn?: string;
    readonly cloudWatchLogGroupName?: string;
    readonly cloudWatchEncryptionKeyArn?: string;
    readonly cloudWatchLogGroupStreamPrefix?: string;
    readonly cloudWatchLogtypes?: string;
    readonly tags?: {
        [key: string]: any;
    };
}
/**
 * Configuration for the EMR Serverless Job API.
 * Use this interface when EmrServerlessJobProps doesn't give you access to the configuration parameters you need.
 * @param jobConfig The job configuration. @link[https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_StartJobRun.html]
 */
export interface SparkEmrServerlessJobApiProps extends SparkJobProps {
    /**
     * EMR Serverless Job Configuration.
     * @link[https://docs.aws.amazon.com/emr-serverless/latest/APIReference/API_StartJobRun.html]
     */
    readonly jobConfig: {
        [key: string]: any;
    };
}
